@@ -14,8 +14,8 @@ import logging
 
 import pkg_resources
 
-# Import default parameters
-from ffcx.parameters import get_parameters  # noqa: F401
+# Import default options
+from ffcx.options import get_options  # noqa: F401
 
 __version__ = pkg_resources.get_distribution("fenics-ffcx").version
 
