@@ -9,8 +9,8 @@ import logging
 import warnings
 
 import ufl
-from ffcx.element_interface import create_element
-from ufl.finiteelement import MixedElement
+from basix.ufl_wrapper import BlockedElement
+from ffcx.element_interface import convert_element, create_element
 
 logger = logging.getLogger("ffcx")
 
@@ -18,14 +18,14 @@ logger = logging.getLogger("ffcx")
 class FFCXBackendAccess(object):
     """FFCx specific cpp formatter class."""
 
-    def __init__(self, ir, language, symbols, parameters):
+    def __init__(self, ir, language, symbols, options):
 
-        # Store ir and parameters
+        # Store ir and options
         self.entitytype = ir.entitytype
         self.integral_type = ir.integral_type
         self.language = language
         self.symbols = symbols
-        self.parameters = parameters
+        self.options = options
 
         # Lookup table for handler to call when the "get" method (below) is
         # called, depending on the first argument type.
@@ -179,7 +179,7 @@ class FFCXBackendAccess(object):
 
     def reference_cell_volume(self, e, mt, tabledata, access):
         L = self.language
-        cellname = mt.terminal.ufl_domain().ufl_cell().cellname()
+        cellname = ufl.domain.extract_unique_domain(mt.terminal).ufl_cell().cellname()
         if cellname in ("interval", "triangle", "tetrahedron", "quadrilateral", "hexahedron"):
             return L.Symbol(f"{cellname}_reference_cell_volume")
         else:
@@ -187,7 +187,7 @@ class FFCXBackendAccess(object):
 
     def reference_facet_volume(self, e, mt, tabledata, access):
         L = self.language
-        cellname = mt.terminal.ufl_domain().ufl_cell().cellname()
+        cellname = ufl.domain.extract_unique_domain(mt.terminal).ufl_cell().cellname()
         if cellname in ("interval", "triangle", "tetrahedron", "quadrilateral", "hexahedron"):
             return L.Symbol(f"{cellname}_reference_facet_volume")
         else:
@@ -195,7 +195,7 @@ class FFCXBackendAccess(object):
 
     def reference_normal(self, e, mt, tabledata, access):
         L = self.language
-        cellname = mt.terminal.ufl_domain().ufl_cell().cellname()
+        cellname = ufl.domain.extract_unique_domain(mt.terminal).ufl_cell().cellname()
         if cellname in ("interval", "triangle", "tetrahedron", "quadrilateral", "hexahedron"):
             table = L.Symbol(f"{cellname}_reference_facet_normals")
             facet = self.symbols.entity("facet", mt.restriction)
@@ -205,7 +205,7 @@ class FFCXBackendAccess(object):
 
     def cell_facet_jacobian(self, e, mt, tabledata, num_points):
         L = self.language
-        cellname = mt.terminal.ufl_domain().ufl_cell().cellname()
+        cellname = ufl.domain.extract_unique_domain(mt.terminal).ufl_cell().cellname()
         if cellname in ("triangle", "tetrahedron", "quadrilateral", "hexahedron"):
             table = L.Symbol(f"{cellname}_reference_facet_jacobian")
             facet = self.symbols.entity("facet", mt.restriction)
@@ -217,7 +217,7 @@ class FFCXBackendAccess(object):
 
     def reference_cell_edge_vectors(self, e, mt, tabledata, num_points):
         L = self.language
-        cellname = mt.terminal.ufl_domain().ufl_cell().cellname()
+        cellname = ufl.domain.extract_unique_domain(mt.terminal).ufl_cell().cellname()
         if cellname in ("triangle", "tetrahedron", "quadrilateral", "hexahedron"):
             table = L.Symbol(f"{cellname}_reference_edge_vectors")
             return table[mt.component[0]][mt.component[1]]
@@ -228,7 +228,7 @@ class FFCXBackendAccess(object):
 
     def reference_facet_edge_vectors(self, e, mt, tabledata, num_points):
         L = self.language
-        cellname = mt.terminal.ufl_domain().ufl_cell().cellname()
+        cellname = ufl.domain.extract_unique_domain(mt.terminal).ufl_cell().cellname()
         if cellname in ("tetrahedron", "hexahedron"):
             table = L.Symbol(f"{cellname}_reference_edge_vectors")
             facet = self.symbols.entity("facet", mt.restriction)
@@ -242,7 +242,7 @@ class FFCXBackendAccess(object):
 
     def facet_orientation(self, e, mt, tabledata, num_points):
         L = self.language
-        cellname = mt.terminal.ufl_domain().ufl_cell().cellname()
+        cellname = ufl.domain.extract_unique_domain(mt.terminal).ufl_cell().cellname()
         if cellname not in ("interval", "triangle", "tetrahedron"):
             raise RuntimeError(f"Unhandled cell types {cellname}.")
 
@@ -252,19 +252,19 @@ class FFCXBackendAccess(object):
 
     def cell_vertices(self, e, mt, tabledata, num_points):
         # Get properties of domain
-        domain = mt.terminal.ufl_domain()
+        domain = ufl.domain.extract_unique_domain(mt.terminal)
         gdim = domain.geometric_dimension()
-        coordinate_element = domain.ufl_coordinate_element()
+        coordinate_element = convert_element(domain.ufl_coordinate_element())
 
         # Get dimension and dofmap of scalar element
-        assert isinstance(coordinate_element, MixedElement)
+        assert isinstance(coordinate_element, BlockedElement)
         assert coordinate_element.value_shape() == (gdim, )
         ufl_scalar_element, = set(coordinate_element.sub_elements())
-        assert ufl_scalar_element.family() in ("Lagrange", "Q", "S")
+        scalar_element = create_element(ufl_scalar_element)
+        assert scalar_element.value_size == 1 and scalar_element.block_size == 1
 
-        basix_scalar_element = create_element(ufl_scalar_element)
-        vertex_scalar_dofs = basix_scalar_element.entity_dofs[0]
-        num_scalar_dofs = basix_scalar_element.dim
+        vertex_scalar_dofs = scalar_element.entity_dofs[0]
+        num_scalar_dofs = scalar_element.dim
 
         # Get dof and component
         dof, = vertex_scalar_dofs[mt.component[0]]
@@ -275,10 +275,10 @@ class FFCXBackendAccess(object):
 
     def cell_edge_vectors(self, e, mt, tabledata, num_points):
         # Get properties of domain
-        domain = mt.terminal.ufl_domain()
+        domain = ufl.domain.extract_unique_domain(mt.terminal)
         cellname = domain.ufl_cell().cellname()
         gdim = domain.geometric_dimension()
-        coordinate_element = domain.ufl_coordinate_element()
+        coordinate_element = convert_element(domain.ufl_coordinate_element())
 
         if cellname in ("triangle", "tetrahedron", "quadrilateral", "hexahedron"):
             pass
@@ -288,18 +288,18 @@ class FFCXBackendAccess(object):
             raise RuntimeError(f"Unhandled cell types {cellname}.")
 
         # Get dimension and dofmap of scalar element
-        assert isinstance(coordinate_element, MixedElement)
+        assert isinstance(coordinate_element, BlockedElement)
         assert coordinate_element.value_shape() == (gdim, )
         ufl_scalar_element, = set(coordinate_element.sub_elements())
-        assert ufl_scalar_element.family() in ("Lagrange", "Q", "S")
+        scalar_element = create_element(ufl_scalar_element)
+        assert scalar_element.value_size == 1 and scalar_element.block_size == 1
 
-        basix_scalar_element = create_element(ufl_scalar_element)
-        vertex_scalar_dofs = basix_scalar_element.entity_dofs[0]
-        num_scalar_dofs = basix_scalar_element.dim
+        vertex_scalar_dofs = scalar_element.entity_dofs[0]
+        num_scalar_dofs = scalar_element.dim
 
         # Get edge vertices
         edge = mt.component[0]
-        vertex0, vertex1 = basix_scalar_element.reference_topology[1][edge]
+        vertex0, vertex1 = scalar_element.reference_topology[1][edge]
 
         # Get dofs and component
         dof0, = vertex_scalar_dofs[vertex0]
@@ -316,10 +316,10 @@ class FFCXBackendAccess(object):
         L = self.language
 
         # Get properties of domain
-        domain = mt.terminal.ufl_domain()
+        domain = ufl.domain.extract_unique_domain(mt.terminal)
         cellname = domain.ufl_cell().cellname()
         gdim = domain.geometric_dimension()
-        coordinate_element = domain.ufl_coordinate_element()
+        coordinate_element = convert_element(domain.ufl_coordinate_element())
 
         if cellname in ("tetrahedron", "hexahedron"):
             pass
@@ -330,13 +330,14 @@ class FFCXBackendAccess(object):
             raise RuntimeError(f"Unhandled cell types {cellname}.")
 
         # Get dimension and dofmap of scalar element
-        assert isinstance(coordinate_element, MixedElement)
+        assert isinstance(coordinate_element, BlockedElement)
         assert coordinate_element.value_shape() == (gdim, )
         ufl_scalar_element, = set(coordinate_element.sub_elements())
-        assert ufl_scalar_element.family() in ("Lagrange", "Q", "S")
+        scalar_element = create_element(ufl_scalar_element)
+        assert scalar_element.value_size == 1 and scalar_element.block_size == 1
 
-        basix_scalar_element = create_element(ufl_scalar_element)
-        num_scalar_dofs = basix_scalar_element.dim
+        scalar_element = create_element(ufl_scalar_element)
+        num_scalar_dofs = scalar_element.dim
 
         # Get edge vertices
         facet = self.symbols.entity("facet", mt.restriction)
