@@ -5,7 +5,7 @@
 
 from typing import Optional
 
-import ffcx.parameters
+import ffcx.options
 import ufl
 from ffcx.analysis import analyze_ufl_objects
 from ffcx.codegeneration.backend import FFCXBackend
@@ -13,18 +13,18 @@ from ffcx.codegeneration.integrals import IntegralGenerator
 from ffcx.ir.representation import compute_ir
 
 
-def count_flops(form: ufl.Form, parameters: Optional[dict] = {}):
+def count_flops(form: ufl.Form, options: Optional[dict] = {}):
     """Return a list with the number of flops for each kernel in the Form."""
-    parameters = ffcx.parameters.get_parameters(parameters)
+    options = ffcx.options.get_options(options)
     assert isinstance(form, ufl.Form)
-    analysis = analyze_ufl_objects([form], parameters)
-    ir = compute_ir(analysis, {}, "flops", parameters, False)
+    analysis = analyze_ufl_objects([form], options)
+    ir = compute_ir(analysis, {}, "flops", options, False)
 
     flops = []
 
     for integral_ir in ir.integrals:
         # Create FFCx C backend
-        backend = FFCXBackend(integral_ir, parameters)
+        backend = FFCXBackend(integral_ir, options)
         # Configure kernel generator
         ig = IntegralGenerator(integral_ir, backend)
         # Generate code ast for the tabulate_tensor body
