@@ -6,7 +6,7 @@
 
 import collections
 import logging
-from typing import List, Tuple
+from typing import Any, Dict, List, Set, Tuple
 
 import ufl
 from ffcx.codegeneration import geometry
@@ -22,7 +22,7 @@ from ffcx.naming import cdtype_to_numpy, scalar_to_value_type
 logger = logging.getLogger("ffcx")
 
 
-def generator(ir, parameters):
+def generator(ir, options):
     logger.info("Generating code for integral:")
     logger.info(f"--- type: {ir.integral_type}")
     logger.info(f"--- name: {ir.name}")
@@ -34,7 +34,7 @@ def generator(ir, parameters):
     declaration = ufcx_integrals.declaration.format(factory_name=factory_name)
 
     # Create FFCx C backend
-    backend = FFCXBackend(ir, parameters)
+    backend = FFCXBackend(ir, options)
 
     # Configure kernel generator
     ig = IntegralGenerator(ir, backend)
@@ -68,7 +68,7 @@ def generator(ir, parameters):
     code["additional_includes_set"] = set()  # FIXME: Get this out of code[]
     code["tabulate_tensor"] = body
 
-    if parameters["tabulate_tensor_void"]:
+    if options["tabulate_tensor_void"]:
         code["tabulate_tensor"] = ""
 
     implementation = ufcx_integrals.factory.format(
@@ -77,9 +77,9 @@ def generator(ir, parameters):
         enabled_coefficients_init=code["enabled_coefficients_init"],
         tabulate_tensor=code["tabulate_tensor"],
         needs_facet_permutations="true" if ir.needs_facet_permutations else "false",
-        scalar_type=parameters["scalar_type"],
-        geom_type=scalar_to_value_type(parameters["scalar_type"]),
-        np_scalar_type=cdtype_to_numpy(parameters["scalar_type"]),
+        scalar_type=options["scalar_type"],
+        geom_type=scalar_to_value_type(options["scalar_type"]),
+        np_scalar_type=cdtype_to_numpy(options["scalar_type"]),
         coordinate_element=L.AddressOf(L.Symbol(ir.coordinate_element)))
 
     return declaration, implementation
@@ -177,11 +177,11 @@ class IntegralGenerator(object):
         assert not any(d for d in self.scopes.values())
 
         parts = []
-        scalar_type = self.backend.access.parameters["scalar_type"]
+        scalar_type = self.backend.access.options["scalar_type"]
         value_type = scalar_to_value_type(scalar_type)
-        alignment = self.ir.params['assume_aligned']
+        alignment = self.ir.options['assume_aligned']
         if alignment != -1:
-            scalar_type = self.backend.access.parameters["scalar_type"]
+            scalar_type = self.backend.access.options["scalar_type"]
             parts += [L.VerbatimStatement(f"A = ({scalar_type}*)__builtin_assume_aligned(A, {alignment});"),
                       L.VerbatimStatement(f"w = (const {scalar_type}*)__builtin_assume_aligned(w, {alignment});"),
                       L.VerbatimStatement(f"c = (const {scalar_type}*)__builtin_assume_aligned(c, {alignment});"),
@@ -238,7 +238,7 @@ class IntegralGenerator(object):
         if self.ir.integral_type in skip:
             return parts
 
-        padlen = self.ir.params["padlen"]
+        padlen = self.ir.options["padlen"]
 
         # Loop over quadrature rules
         for quadrature_rule, integrand in self.ir.integrand.items():
@@ -253,7 +253,7 @@ class IntegralGenerator(object):
         parts = L.commented_code_list(parts, "Quadrature rules")
         return parts
 
-    def generate_geometry_tables(self, float_type):
+    def generate_geometry_tables(self, float_type: str):
         """Generate static tables of geometry data."""
         L = self.backend.language
 
@@ -267,7 +267,7 @@ class IntegralGenerator(object):
             ufl.geometry.ReferenceNormal: "reference_facet_normals",
             ufl.geometry.FacetOrientation: "facet_orientation"
         }
-        cells = {t: set() for t in ufl_geometry.keys()}
+        cells: Dict[Any, Set[Any]] = {t: set() for t in ufl_geometry.keys()}
 
         for integrand in self.ir.integrand.values():
             for attr in integrand["factorization"].nodes.values():
@@ -275,7 +275,7 @@ class IntegralGenerator(object):
                 if mt is not None:
                     t = type(mt.terminal)
                     if t in ufl_geometry:
-                        cells[t].add(mt.terminal.ufl_domain().ufl_cell().cellname())
+                        cells[t].add(ufl.domain.extract_unique_domain(mt.terminal).ufl_cell().cellname())
 
         parts = []
         for i, cell_list in cells.items():
@@ -290,7 +290,7 @@ class IntegralGenerator(object):
         parts = []
         tables = self.ir.unique_tables
         table_types = self.ir.unique_table_types
-        padlen = self.ir.params["padlen"]
+        padlen = self.ir.options["padlen"]
         if self.ir.integral_type in ufl.custom_integral_types:
             # Define only piecewise tables
             table_names = [name for name in sorted(tables) if table_types[name] in piecewise_ttypes]
@@ -445,7 +445,7 @@ class IntegralGenerator(object):
                             vaccess = symbol[j]
                             intermediates.append(L.Assign(vaccess, vexpr))
                         else:
-                            scalar_type = self.backend.access.parameters["scalar_type"]
+                            scalar_type = self.backend.access.options["scalar_type"]
                             vaccess = L.Symbol("%s_%d" % (symbol.name, j))
                             intermediates.append(L.VariableDecl(f"const {scalar_type}", vaccess, vexpr))
 
@@ -459,8 +459,8 @@ class IntegralGenerator(object):
 
         if intermediates:
             if use_symbol_array:
-                padlen = self.ir.params["padlen"]
-                parts += [L.ArrayDecl(self.backend.access.parameters["scalar_type"],
+                padlen = self.ir.options["padlen"]
+                parts += [L.ArrayDecl(self.backend.access.options["scalar_type"],
                                       symbol, len(intermediates), padlen=padlen)]
             parts += intermediates
         return pre_definitions, parts
@@ -527,7 +527,7 @@ class IntegralGenerator(object):
     def generate_block_parts(self, quadrature_rule: QuadratureRule, blockmap: Tuple, blocklist: List[BlockDataT]):
         """Generate and return code parts for a given block.
 
-        Returns parts occuring before, inside, and after the quadrature
+        Returns parts occurring before, inside, and after the quadrature
         loop identified by the quadrature rule.
 
         Should be called with quadrature_rule=None for
@@ -539,7 +539,7 @@ class IntegralGenerator(object):
         preparts: List[CNode] = []
         quadparts: List[CNode] = []
 
-        # RHS expressiong grouped by LHS "dofmap"
+        # RHS expressions grouped by LHS "dofmap"
         rhs_expressions = collections.defaultdict(list)
 
         block_rank = len(blockmap)
@@ -589,7 +589,7 @@ class IntegralGenerator(object):
                 key = (quadrature_rule, factor_index, blockdata.all_factors_piecewise)
                 fw, defined = self.get_temp_symbol("fw", key)
                 if not defined:
-                    scalar_type = self.backend.access.parameters["scalar_type"]
+                    scalar_type = self.backend.access.options["scalar_type"]
                     quadparts.append(L.VariableDecl(f"const {scalar_type}", fw, fw_rhs))
 
             assert not blockdata.transposed, "Not handled yet"
@@ -657,7 +657,7 @@ class IntegralGenerator(object):
                         keep[indices].append(L.float_product([statement, lhs]))
                     else:
                         t = self.new_temp_symbol("t")
-                        scalar_type = self.backend.access.parameters["scalar_type"]
+                        scalar_type = self.backend.access.options["scalar_type"]
                         pre_loop.append(L.ArrayDecl(scalar_type, t, blockdims[0]))
                         keep[indices].append(L.float_product([statement, t[B_indices[0]]]))
                         hoist.append(L.Assign(t[B_indices[i - 1]], sum))
