@@ -9,9 +9,10 @@ import logging
 import typing
 
 import numpy
+
 import ufl
 import ufl.utils.derivativetuples
-from ffcx.element_interface import basix_index, convert_element
+from ffcx.element_interface import basix_index, convert_element, QuadratureElement
 from ffcx.ir.representationutils import (create_quadrature_points_and_weights,
                                          integral_type_to_entity_dim,
                                          map_integral_points)
@@ -101,9 +102,13 @@ def get_ffcx_table_values(points, cell, integral_type, element, avg, entitytype,
         elif avg == "facet":
             integral_type = "exterior_facet"
 
-        # Make quadrature rule and get points and weights
-        points, weights = create_quadrature_points_and_weights(integral_type, cell,
-                                                               element.degree(), "default")
+        if isinstance(element, QuadratureElement):
+            points = element._points
+            weights = element._weights
+        else:
+            # Make quadrature rule and get points and weights
+            points, weights = create_quadrature_points_and_weights(
+                integral_type, cell, element.highest_degree(), "default")
 
     # Tabulate table of basis functions and derivatives in points for each entity
     tdim = cell.topological_dimension()
@@ -182,7 +187,7 @@ def generate_psi_table_name(quadrature_rule, element_counter, averaged: str, ent
 def get_modified_terminal_element(mt) -> typing.Optional[ModifiedTerminalElement]:
     gd = mt.global_derivatives
     ld = mt.local_derivatives
-
+    domain = ufl.domain.extract_unique_domain(mt.terminal)
     # Extract element from FormArguments and relevant GeometricQuantities
     if isinstance(mt.terminal, ufl.classes.FormArgument):
         if gd and mt.reference_value:
@@ -198,7 +203,7 @@ def get_modified_terminal_element(mt) -> typing.Optional[ModifiedTerminalElement
             raise RuntimeError("Not expecting reference value of x.")
         if gd:
             raise RuntimeError("Not expecting global derivatives of x.")
-        element = convert_element(mt.terminal.ufl_domain().ufl_coordinate_element())
+        element = convert_element(domain.ufl_coordinate_element())
         if not ld:
             fc = mt.flat_component
         else:
@@ -211,7 +216,7 @@ def get_modified_terminal_element(mt) -> typing.Optional[ModifiedTerminalElement
             raise RuntimeError("Not expecting reference value of J.")
         if gd:
             raise RuntimeError("Not expecting global derivatives of J.")
-        element = convert_element(mt.terminal.ufl_domain().ufl_coordinate_element())
+        element = convert_element(domain.ufl_coordinate_element())
         assert len(mt.component) == 2
         # Translate component J[i,d] to x element context rgrad(x[i])[d]
         fc, d = mt.component  # x-component, derivative
@@ -221,7 +226,7 @@ def get_modified_terminal_element(mt) -> typing.Optional[ModifiedTerminalElement
 
     assert (mt.averaged is None) or not (ld or gd)
     # Change derivatives format for table lookup
-    gdim = mt.terminal.ufl_domain().geometric_dimension()
+    gdim = domain.geometric_dimension()
     local_derivatives = ufl.utils.derivativetuples.derivative_listing_to_counts(
         ld, gdim)
 
